package lightcontainer.protocol.rules.reader;

import lightcontainer.domains.client.Context;
import lightcontainer.protocol.ProtocolReader;

/**
 * Règle permettant d'être alerter de l'annoncement d'un SBE
 */
public class HelloRule extends ProtocolReader {

    private static final String PATTERN = "^HELLO ([A-Za-z0-9.]{5,20}) ([\\d]{0,5})\r\n$";

    private static final String NAME = "HELLO";

    // Index du domain dans le tableau de donnée
    private static final int DOMAIN = 0;

    //Index du port dans le tableau de donnée
    private static final int PORT = 1;

    public HelloRule() {
        super(NAME, PATTERN);
    }


    public class Result extends ProtocolResult {

        private final String domain;
        private final int port;

        public Result(Context context, String domain, int port) {
            super(context);
            this.domain = domain;
            this.port = port;
        }

        public String getDomain() {
            return domain;
        }

        public int getPort() {
            return port;
        }

    }


    @Override
    protected HelloRule.Result onExecuted(Context context, String... data) {
        String domain = data[DOMAIN];
        int port = Integer.parseInt(data[PORT]);

        return new HelloRule.Result(context, domain, port);
    }

}
